<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="45"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="48"/>
        <source>Main developers</source>
        <translation>Desarrolladores principales</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="62"/>
        <source>A&amp;uthors</source>
        <translation>A&amp;utores</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="66"/>
        <source>Translation</source>
        <translation>Traducción</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="67"/>
        <source>Czech</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="68"/>
        <source>Slovenian</source>
        <translation>Esloveno</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="69"/>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="77"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="78"/>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="79"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="80"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="81"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="82"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="83"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="85"/>
        <source>Logo</source>
        <translation>Logo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="87"/>
        <source>Coordinating</source>
        <translation>Coordinación</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="91"/>
        <source>Testing</source>
        <translation>Pruebas</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="103"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;Agradecemos a</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="108"/>
        <source>&amp;Licence Agreement</source>
        <translation>&amp;Licencia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="110"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="123"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="40"/>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation>Esta es la aplicación Stopmotion, para crear animaciones de stop motion.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="70"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="72"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="74"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="75"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="52"/>
        <source>Contributors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="64"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="357"/>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation>Debajo puede determinar cuál dispositivo empleará Stopmotion para capturar imágenes y mostrar vídeo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="66"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="359"/>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation>Puede seleccionar uno de los dispositivos autodetectados desde abajo, o añadir dispositivos manualmente. No se recomienda el uso de dispositivos que no han sido detectados automáticamente, pero si Ud. es un usuario con experiencia siéntase libre de hacerlo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="69"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="362"/>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation>El dispositivo seleccionado se reconoce como &lt;b&gt;$VIDEODEVICE&lt;/b&gt; cuando se importa vídeo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="89"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="369"/>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="93"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="370"/>
        <source>&amp;Remove</source>
        <translation>&amp;Quitar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="96"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="371"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="100"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="374"/>
        <source>Video device settings</source>
        <translation>Preferencias del dispositivo de vídeo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="109"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="375"/>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation>Dispositivo de vídeo ($VIDEODEVICE):</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="157"/>
        <source>device</source>
        <translation>dispositivo</translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="385"/>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="386"/>
        <source>&amp;Remove</source>
        <translation>&amp;Quitar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="387"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="94"/>
        <source>Encoder settings</source>
        <translation>Preferencias del codificador</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="104"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="390"/>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation>¿Desea que se le pregunte por el archivo de salida cada vez que exporte?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="106"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="392"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="111"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="393"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="116"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="394"/>
        <source>Set default output file:</source>
        <translation>Archivo de salida predeterminado:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="122"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="395"/>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="127"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="396"/>
        <source>Start encoder:</source>
        <translation>Iniciar codificador:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="132"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="397"/>
        <source>Stop encoder:</source>
        <translation>Detener codificador:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="361"/>
        <source>Choose output file</source>
        <translation>Seleccionar archivo de salida</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="371"/>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation>Debajo puede determinar qué programa/proceso empleará Stopmotion para codificar el proyecto activo a un archivo de vídeo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="373"/>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation>Siempre debería usar &lt;b&gt;$IMAGEPATH&lt;/b&gt; y &lt;b&gt;$VIDEOFILE&lt;/b&gt; para representar la ruta a las imágenes y el archivo de vídeo, respectivamente.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="375"/>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="377"/>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation>Ejemplo con mencoder (imágenes jpeg a vídeo mpeg4):</translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="44"/>
        <source>Input to program:</source>
        <translation>Entrada al programa:</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="54"/>
        <source>Submit</source>
        <translation>Publicar</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="60"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="73"/>
        <source>Output from external command</source>
        <translation>Salida de un comando externo</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Result</source>
        <translation>Resultado</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <source>Failed!</source>
        <translation>¡Operación fallida!</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Successful!</source>
        <translation>¡Operación exitosa!</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="32"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framebar/framebar.cpp" line="194"/>
        <source>Frame number: </source>
        <translation>Cuadro número:</translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="114"/>
        <source>Add &amp;sound</source>
        <translation>Añadir &amp;sonido</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="115"/>
        <source>&amp;Remove Sound</source>
        <translation>&amp;Quitar sonido</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="116"/>
        <source>Change name</source>
        <translation>Cambiar nombre</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="117"/>
        <source>Sounds:</source>
        <translation>Sonidos:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="120"/>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Añadir sonido&lt;/h4&gt; &lt;p&gt;Con este botón puede &lt;em&gt;añadir sonidos&lt;/em&gt; al cuadro seleccionado.&lt;/p&gt; &lt;p&gt;El sonido comenzará a reproducirse cuando se muestre este cuadro, hasta que llegue al final.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="128"/>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Quitar sonido&lt;/h4&gt; &lt;p&gt;Con este botón puede &lt;em&gt;quitar&lt;/em&gt; el sonido seleccionado de este cuadro.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="135"/>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cambiar nombre&lt;/h4&gt; &lt;p&gt;Con este botón puede cambiar el nombre del sonido seleccionado. &lt;BR&gt;El nombre del sonido sólo tiene el objetivo de hacer más fácil el trabajo de animación.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="143"/>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Sonidos&lt;/h4&gt; &lt;p&gt;Esta lista muestra todos los sonidos conectados con este cuadro.&lt;/p&gt;&lt;p&gt;Estos sonidos se empezarán a reproducir cuando se muestre este cuadro, y hasta que finalicen.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation>La captura ha fallado. Esto pudo haber sucedido si Ud. intentó
capturar desde un dispositivo inválido. Por favor chequee los ajustes 
del capturador en el menú de preferencias.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>Debe definir un capturador de imágenes a emplear. Éste se puede determinar en el menú de preferencias.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <source>Pre poll command does not exists</source>
        <translation>El comando de preconsulta no existe</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <source>You do not have the given grabber installed on your system</source>
        <translation>El capturador que ha proporcionado no se encuentra instalado en su sistema</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <source>No video device selected in the preferences menu.</source>
        <translation>No se ha seleccionado ningún dispositivo de vídeo en el menú de preferencias.</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="324"/>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="325"/>
        <source>&amp;Remove</source>
        <translation>&amp;Quitar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="326"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="94"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="328"/>
        <source>Import device settings</source>
        <translation>Importar los ajustes del dispositivo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="103"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="329"/>
        <source>Pre-poll command</source>
        <translation>Comando de preconsulta</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="110"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="330"/>
        <source>Start daemon</source>
        <translation>Iniciar demonio</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="117"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="331"/>
        <source>Stop daemon</source>
        <translation>Detener demonio</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="59"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="315"/>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation>Debajo puede determinar qué programa/proceso empleará Stopmotion para capturar imágenes desde el dispositivo seleccionado.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="61"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="317"/>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation>Siempre debería usar &lt;b&gt;$VIDEODEVICE&lt;/b&gt; y &lt;b&gt;$IMAGEFILE&lt;/b&gt; para representar el dispositiovo de vídeo y el archivo de imagen, respectivamente.</translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="105"/>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="87"/>
        <source>English</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="89"/>
        <source>&amp;Translation</source>
        <translation>&amp;Traducción</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="16"/>
        <source>Stopmotion Help Browser</source>
        <translation>Navegador de la ayuda de Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="40"/>
        <source>Backward</source>
        <translation>Hacia atrás</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="50"/>
        <source>Forward</source>
        <translation>Hacia adelante</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="86"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="153"/>
        <source>Ready to rumble ;-)</source>
        <translation>Listo para luchar :)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="503"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="504"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="590"/>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Abrir&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Abre&lt;/em&gt; un archivo de proyecto de Stopmotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="505"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="506"/>
        <source>Save &amp;As</source>
        <translation>Guardar &amp;como</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="509"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="631"/>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Salir&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Finaliza&lt;/em&gt; el programa.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="374"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="534"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="510"/>
        <source>&amp;Undo</source>
        <translation>Des&amp;hacer</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="641"/>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Deshacer&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Revierte&lt;/em&gt; la última operación. Puede deshacer varias veces para revertir las operaciones anteriores.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="511"/>
        <source>Re&amp;do</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="650"/>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Rehacer&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Rehace&lt;/em&gt; la última operación. Puede presionar este botón varias veces para rehacer varias operaciones.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="512"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="659"/>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cortar&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Corta&lt;/em&gt; los cuadros seleccionados de la animación, y los añade a la papelera para que puedan pegarse en otro lugar.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="513"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="668"/>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Copiar&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copia&lt;/em&gt; los cuadros seleccionados a la papelera. Luego puede pegarlos en otro lugar.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="514"/>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="677"/>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Pegar&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pega&lt;/em&gt; los cuadros que se encuentran en la papelera a la locación seleccionada.&lt;/p&gt; &lt;p&gt;Puede copiar/cortar imágenes desde otros programas y luego usar esta opción para pegarlas en la animación.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="515"/>
        <source>&amp;Go to frame</source>
        <translation>&amp;Ir al cuadro</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="687"/>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ir al cuadro&lt;/h4&gt; &lt;p&gt;Esto hace aparecer un menú debajo, en el que puede escoger el cuadro al que desee &lt;em&gt;ir&lt;/em&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="378"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="563"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="395"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="558"/>
        <source>&amp;Settings</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="517"/>
        <source>What&apos;s &amp;This</source>
        <translation>Qué es es&amp;to</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="707"/>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Qué es esto&lt;/h4&gt; &lt;p&gt;Esto le proporciona un cursor de ratón QuéEsEsto, el que puede ser empleado para obtener información importante, como esta.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="519"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="724"/>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Acerca de&lt;/h4&gt; &lt;p&gt;Esto muestra una ventana en la que se puede leer información general, así como los nombres de los desarrolladores que hay detrás de esta excelente pieza de software.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="398"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="518"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="565"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="769"/>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Barra de cuadros&lt;/h4&gt; &lt;p&gt;En este área puede ver los cuadros y las escenas que hay en las animaciones, y construir la animación moviéndolos de un lado a otro.&lt;/p&gt;&lt;p&gt;Puede cambiar al cuadro siguiente y al anterior empleando las &lt;b&gt;teclas con flechas&lt;/b&gt; o las teclas &lt;b&gt;x&lt;/b&gt; y &lt;b&gt;z&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="763"/>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Menú de herramientas&lt;/h4&gt; &lt;p&gt;Este es el menú de herramientas, en el que se encuentran la mayor parte de los botones y elementos que necesita al trbajar en animaciones de stop motion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="756"/>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Menú de preferencias del cuadro&lt;/h4&gt; &lt;p&gt;En este menú puede determinar preferencias para el cuadro o los cuadros seleccionados, tales como &lt;b&gt;subtítulos&lt;/b&gt; y &lt;b&gt;efectos de sonido&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="750"/>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Menú Ir al cuadro&lt;/h4&gt; &lt;p&gt;Aquí puede especificar un número de cuadro, y el programa saltará al mismo&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="524"/>
        <source>Go to frame:</source>
        <translation>Ir al cuadro:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="736"/>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Número de cuadro&lt;/h4&gt;&lt;p&gt;Este área muestra el número del cuadro seleccionado actualmente.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="743"/>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vista del cuadro&lt;/h4&gt;&lt;p&gt; En este área puede ver el cuadro seleccionado. Además puede reproducir animaciones en esta ventana presionando el botón &lt;b&gt;Reproducir&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="782"/>
        <source>Unsaved changes</source>
        <translation>Cambios no guardados</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="783"/>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>Hay cambios no guardados. ¿Desea guardarlos?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="507"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="375"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="547"/>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="581"/>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nuevo&lt;/h4&gt; &lt;p&gt;Crea un proyecto &lt;em&gt;nuevo&lt;/em&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="598"/>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Guardar&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Guarda&lt;/em&gt; la animación actual como un archivo de proyecto de Stopmotion. &lt;BR&gt;Si este proyecto ya se ha guardado con anterioridad, se vuelve a guardar automáticamente en el archivo previamente seleccionado.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="608"/>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Guardar como&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Guarda&lt;/em&gt; la animación actual como un archivo de proyecto de Stopmotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="617"/>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Vídeo&lt;/h4&gt; &lt;p&gt;Exporta el proyecto actual como &lt;em&gt;vídeo&lt;/em&gt;.&lt;/p&gt;Se le proporciona un asistente para guiarlo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="624"/>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exporta la animación actual como un proyecto de &lt;em&gt;Cinerella&lt;/em&gt;.&lt;/p&gt;Se le proporciona un asistente para guiarlo.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="508"/>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="516"/>
        <source>&amp;Configure Stopmotion</source>
        <translation>&amp;Configurar Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="376"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="1148"/>
        <source>Open &amp;Recent</source>
        <translation>Abrir &amp;reciente</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="586"/>
        <source>New project</source>
        <translation>Proyecto nuevo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="594"/>
        <source>Open project</source>
        <translation>Abrir proyecto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="604"/>
        <source>Save project</source>
        <translation>Guardar proyecto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="613"/>
        <source>Save project As</source>
        <translation>Guardar proyecto como</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="635"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="646"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="655"/>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="664"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="673"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="683"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="692"/>
        <source>Go to frame</source>
        <translation>Ir al cuadro</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="696"/>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Configurar Stopmotion&lt;/h4&gt; &lt;p&gt;Esto abre una ventana en donde puede &lt;em&gt;configurar&lt;/em&gt; Stopmotion con varios dispositivos de entrada y salida.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="701"/>
        <source>Configure Stopmotion</source>
        <translation>Configurar Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="712"/>
        <source>What&apos;s This</source>
        <translation>Qué es esto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="730"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Do&amp;n&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="911"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="963"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="912"/>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation>No se puede hallar ningún codificador registrado
para emplearlo al exportar vídeo. Éstos se pueden determinar
en el menú de preferencias. No le será posible exportar a vídeo
hasta que no tenga determinado un codificador para usar.
¿Desea determianrlo ahora?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="948"/>
        <source>Export to video file</source>
        <translation>Exportar a un archivo de vídeo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="964"/>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation>El codificador registrado no es válido. ¿Podría chequear
sus ajustes en el menú de preferencias?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="980"/>
        <source>Export to file</source>
        <translation>Exportar al archivo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="716"/>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ayuda&lt;/h4&gt; &lt;p&gt;Este botón hace aparecer un diálogo que contiene el manual de Stopmotion&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="720"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="522"/>
        <source>Frame number: </source>
        <translation>Cuadro número:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="816"/>
        <source>Choose project file</source>
        <translation>Seleccionar archivo de proyecto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="884"/>
        <source>Save As</source>
        <translation>Guardar como</translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="58"/>
        <source>Choose frames to add</source>
        <translation>Seleccione los cuadros a añadir</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="179"/>
        <source>Removed the selected frame</source>
        <translation>El cuadro seleccionado se ha quitado</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="216"/>
        <location filename="../src/application/modelhandler.cpp" line="227"/>
        <location filename="../src/application/modelhandler.cpp" line="244"/>
        <source>Warning</source>
        <translation type="unfinished">Advertencia</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="217"/>
        <source>You do not have Gimp installed on your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="228"/>
        <source>There is no active frame to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="245"/>
        <source>Failed to start Gimp!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="73"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="119"/>
        <source>Video &amp;Import</source>
        <translation>&amp;Importar vídeo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="82"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="120"/>
        <source>Video &amp;Export</source>
        <translation>&amp;Exportar vídeo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="39"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="114"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="43"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="115"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="57"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="116"/>
        <source>Preferences Menu</source>
        <translation>Menú de preferencias</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="91"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="118"/>
        <source>Video &amp;Device</source>
        <translation>&amp;Dispositivo de vídeo</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="192"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="207"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="196"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="204"/>
        <source>Fatal</source>
        <translation>Fatal</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="120"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">vgrabbj VGA singleshot</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="278"/>
        <source>vgrabbj VGA daemon</source>
        <translation>demonio vgrabbj VGA</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="280"/>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation>Inicia vgrabbj como un demonio. Es bastante rápido.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="418"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="271"/>
        <source>The simplest setting. Fairly slow</source>
        <translation>El ajuste más simple. Es bastante lento</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="101"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="104"/>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="107"/>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="110"/>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="113"/>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="116"/>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="269"/>
        <source>vgrabbj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="288"/>
        <source>uvccapture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="290"/>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="324"/>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation>Exporta desde imágenes jpeg a vídeo mpeg1</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="368"/>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="411"/>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation>Existe una versión más nueva del archivo de preferencias, que tiene algunos valores predeterminados más. ¿Desea emplearlo? (sus antiguas preferencias se conservarán en ~/.stopmotion/preferences.xml.OLD)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="333"/>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation>Exporta desde imágenes jpeg images a vídeo mpeg2</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="351"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="359"/>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation>Exporta desde imágenes jpeg a vídeo mpeg4</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="306"/>
        <source>dvgrab</source>
        <translation>dvgrab</translation>
    </message>
    <message>
        <source>Grabbing from DV-cam. (EXPERIMENTAL)</source>
        <translation type="obsolete">Capturando desde una DV-cam. (EXPERIMENTAL)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="297"/>
        <source>videodog singleshot</source>
        <translation>videodog singleshot</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="299"/>
        <source>Videodog.</source>
        <translation>Videodog.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="308"/>
        <source>Grabbing from DV-cam.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <location filename="../src/application/runanimationhandler.cpp" line="90"/>
        <source>Running animation</source>
        <translation>Reproduciendo la animación</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Sounds (*.ogg)</source>
        <translation>Sonidos (*.ogg)</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="70"/>
        <source>Sound name</source>
        <translation>Nombre del sonido</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="71"/>
        <source>Enter the name of the sound:</source>
        <translation>Ingrese el nombre del sonido:</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Choose sound file</source>
        <translation>Seleccionar el archivo de sonido</translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="223"/>
        <source>FPS chooser</source>
        <translation>Selector de FPS</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="301"/>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Selector de FPS&lt;/h4&gt; &lt;p&gt;Al cambiar el valor se determina la velocidad a la que se reproduce la animación en el &lt;b&gt;visor de cuadros&lt;/b&gt;.&lt;/p&gt; &lt;p&gt;Para reproducir la animación presione el botón &lt;b&gt;Reproducir animación&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="224"/>
        <source>Number of images:</source>
        <translation>Cantidad de imágenes:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="227"/>
        <source>Mix</source>
        <translation>Mezcla</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="228"/>
        <source>Diff</source>
        <translation>Diferencia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="229"/>
        <source>Playback</source>
        <translation>Previsualizar</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="234"/>
        <source>Per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="235"/>
        <source>Per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="236"/>
        <source>Per hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="241"/>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Añadir cuadros (CTRL+F)&lt;/h4&gt; &lt;p&gt;Haga clic sobre este botón para &lt;em&gt;añadir&lt;/em&gt; cuadros a la animación &lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="248"/>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Quitar la selección (Delete)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se quitan&lt;/em&gt; los cuadros seleccionados de la animación.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="255"/>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Escena nueva (CTRL+E)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se crea&lt;/em&gt; una &lt;em&gt;escena&lt;/em&gt; nueva en la animación.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="262"/>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Quitar la escena(CTRL+E)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se quita&lt;/em&gt; la escena seleccionada de la animación.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="269"/>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Encender/apagar la cámara (C)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón se cambia la cámara entre encendida y apagada&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="282"/>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Capturar un cuadro (Barra espaciadora)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se captura&lt;/em&gt; un cuadro desde la cámara y se coloca en la animación&lt;/p&gt; &lt;p&gt;Esto también puede hacerse presionando la &lt;b&gt;barra espaciadora&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="290"/>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cantidad de imágenes&lt;/h4&gt; &lt;p&gt;Al cambiar este valor en la barra deslizadora se puede especificar cuántas imágenes anteriores de la animación se mezclan sobre la imagen que da la cámara, o si se encuentra en el modo de previsualización: cuántas imágenes reproducir.&lt;/p&gt; &lt;p&gt;Al mezclar las imágenes anteriores con la imagen de la cámara se ve fácilmente la relación que hay entre ellas, haciendo posible lograr movimientos más suaves&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="311"/>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Reproducir la animación (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="314"/>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Detener la animación (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="317"/>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Cuadro anterior (J, Izquierda)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="320"/>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Cuadro siguiente (L, Derecha)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="323"/>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Escena anterior (I)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="326"/>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Escena siguiente (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="330"/>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Bucle de animación (CTRL+L)&lt;/h4&gt; &lt;p&gt;Con este botón puede determinar si la animación se reproduce una vez hasta el final, o si se reproduce una y otra vez indefinidamente.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Notice</source>
        <translation>Nótese</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation>Actualmente, la previsualización sólo está disponible mientras
se emplea el capturador como un demonio. Vaya al
menú de preferencias (CTRL+P) para hacer que el capturador
de la imagen corra como un demonio.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="230"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Pr sec</source>
        <translation type="obsolete">Pr sec</translation>
    </message>
    <message>
        <source>Pr min</source>
        <translation type="obsolete">Pr min</translation>
    </message>
    <message>
        <source>Pr hr</source>
        <translation type="obsolete">Pr hr</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="275"/>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
